/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLObjectElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLObjectElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLObjectElement.h"
#include "gdom/PrivateIntGdomHTMLObjectElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLObjectElement::GDOMHTMLObjectElement(PassRefPtr<WebCore::HTMLObjectElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLObjectElement.h"
#include <gdom/GdomHTMLObjectElement.h>
#include <gdom/PrivateGdomHTMLObjectElement.h>
#include <gdom/PrivateIntGdomHTMLObjectElement.h>
#include <gdom/GdomHTMLObjectElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLObjectElement, gdom_html_object_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLObjectElementPrivate {
    class WebCore::HTMLObjectElement *item;
};

#define GDOM_HTML_OBJECT_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_OBJECT_ELEMENT, GdomHTMLObjectElementPrivate))
*/
G_END_DECLS
WebCore::HTMLObjectElement *
gdom_html_object_element_get_private(GdomHTMLObjectElement *request)
{
    GDOMHTMLObjectElement *res;
    res = static_cast<GDOMHTMLObjectElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLObjectElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_FORM,
    PROP_CODE,
    PROP_ALIGN,
    PROP_ARCHIVE,
    PROP_BORDER,
    PROP_CODE_BASE,
    PROP_CODE_TYPE,
    PROP_DATA,
    PROP_DECLARE,
    PROP_HEIGHT,
    PROP_HSPACE,
    PROP_NAME,
    PROP_STANDBY,
    PROP_TYPE,
    PROP_USE_MAP,
    PROP_VSPACE,
    PROP_WIDTH,
    PROP_CONTENT_DOCUMENT,
};


static void gdom_html_object_element_finalize(GObject* object)
{
    /*GdomHTMLObjectElement* request = GDOM_HTML_OBJECT_ELEMENT(object);*/
    /*GdomHTMLObjectElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_object_element_parent_class)->finalize(object);
}

static void gdom_html_object_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLObjectElement *self = GDOM_HTML_OBJECT_ELEMENT(object);
    WebCore::HTMLObjectElement * gself = (gdom_html_object_element_get_private(self));
    switch (prop_id) {
     case PROP_CODE:
    {
         gself->setCode(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ARCHIVE:
    {
         gself->setArchive(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_BORDER:
    {
         gself->setBorder(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CODE_BASE:
    {
         gself->setCodeBase(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CODE_TYPE:
    {
         gself->setCodeType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DATA:
    {
         gself->setData(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DECLARE:
    {
         gself->setDeclare((g_value_get_boolean (value)) );
         break;
    }
     case PROP_HEIGHT:
    {
         gself->setHeight(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HSPACE:
    {
         gself->setHspace((g_value_get_long (value)) );
         break;
    }
     case PROP_NAME:
    {
         gself->setName(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_STANDBY:
    {
         gself->setStandby(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TYPE:
    {
         gself->setType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_USE_MAP:
    {
         gself->setUseMap(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_VSPACE:
    {
         gself->setVspace((g_value_get_long (value)) );
         break;
    }
     case PROP_WIDTH:
    {
         gself->setWidth(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_object_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLObjectElement *self = GDOM_HTML_OBJECT_ELEMENT(object);
    WebCore::HTMLObjectElement * gself = (gdom_html_object_element_get_private(self));
    switch (prop_id) {
    case PROP_FORM:
    {
         PassRefPtr<WebCore::HTMLFormElement> ptr = gself->form();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_CODE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->code()));
         break;
    }
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_ARCHIVE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->archive()));
         break;
    }
    case PROP_BORDER:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->border()));
         break;
    }
    case PROP_CODE_BASE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->codeBase()));
         break;
    }
    case PROP_CODE_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->codeType()));
         break;
    }
    case PROP_DATA:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->data()));
         break;
    }
    case PROP_DECLARE:
    {
         g_value_set_boolean (value, gself->declare());
         break;
    }
    case PROP_HEIGHT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->height()));
         break;
    }
    case PROP_HSPACE:
    {
         g_value_set_long (value, gself->hspace());
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_STANDBY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->standby()));
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    case PROP_USE_MAP:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->useMap()));
         break;
    }
    case PROP_VSPACE:
    {
         g_value_set_long (value, gself->vspace());
         break;
    }
    case PROP_WIDTH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->width()));
         break;
    }
    case PROP_CONTENT_DOCUMENT:
    {
         PassRefPtr<WebCore::Document> ptr = gself->contentDocument();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_object_element_class_init(GdomHTMLObjectElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_object_element_finalize;
    g_klass->set_property = gdom_html_object_element__set_property_fn;
    g_klass->get_property = gdom_html_object_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_FORM,
            g_param_spec_object ("form", /* name */
                "html_object_element_form", /* short description */
                "read-only  GdomHTMLFormElement * HTMLObjectElement.form", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_FORM_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_CODE,
            g_param_spec_string ("code", /* name */
                "html_object_element_code", /* short description */
                "read-write  gchar * HTMLObjectElement.code", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_object_element_align", /* short description */
                "read-write  gchar * HTMLObjectElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ARCHIVE,
            g_param_spec_string ("archive", /* name */
                "html_object_element_archive", /* short description */
                "read-write  gchar * HTMLObjectElement.archive", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_BORDER,
            g_param_spec_string ("border", /* name */
                "html_object_element_border", /* short description */
                "read-write  gchar * HTMLObjectElement.border", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CODE_BASE,
            g_param_spec_string ("code_base", /* name */
                "html_object_element_code_base", /* short description */
                "read-write  gchar * HTMLObjectElement.code_base", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CODE_TYPE,
            g_param_spec_string ("code_type", /* name */
                "html_object_element_code_type", /* short description */
                "read-write  gchar * HTMLObjectElement.code_type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DATA,
            g_param_spec_string ("data", /* name */
                "html_object_element_data", /* short description */
                "read-write  gchar * HTMLObjectElement.data", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DECLARE,
            g_param_spec_boolean ("declare", /* name */
                "html_object_element_declare", /* short description */
                "read-write  gboolean HTMLObjectElement.declare", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HEIGHT,
            g_param_spec_string ("height", /* name */
                "html_object_element_height", /* short description */
                "read-write  gchar * HTMLObjectElement.height", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HSPACE,
            g_param_spec_long ("hspace", /* name */
                "html_object_element_hspace", /* short description */
                "read-write  glong HTMLObjectElement.hspace", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "html_object_element_name", /* short description */
                "read-write  gchar * HTMLObjectElement.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_STANDBY,
            g_param_spec_string ("standby", /* name */
                "html_object_element_standby", /* short description */
                "read-write  gchar * HTMLObjectElement.standby", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "html_object_element_type", /* short description */
                "read-write  gchar * HTMLObjectElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_USE_MAP,
            g_param_spec_string ("use_map", /* name */
                "html_object_element_use_map", /* short description */
                "read-write  gchar * HTMLObjectElement.use_map", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_VSPACE,
            g_param_spec_long ("vspace", /* name */
                "html_object_element_vspace", /* short description */
                "read-write  glong HTMLObjectElement.vspace", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WIDTH,
            g_param_spec_string ("width", /* name */
                "html_object_element_width", /* short description */
                "read-write  gchar * HTMLObjectElement.width", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CONTENT_DOCUMENT,
            g_param_spec_object ("content_document", /* name */
                "html_object_element_content_document", /* short description */
                "read-only  GdomDocument * HTMLObjectElement.content_document", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOCUMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLObjectElementPrivate));*/
}

static void gdom_html_object_element_init(GdomHTMLObjectElement* request)
{
    /*GdomHTMLObjectElementPrivate* priv = GDOM_HTML_OBJECT_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

